@@ -19,6 +19,7 @@ GNU General Public License for more details.
 import re
 import asyncio
 from time import sleep
+from typing import List, Callable, Any
 from functools import wraps
 from playwright.sync_api import sync_playwright
 from playwright.async_api import async_playwright
@@ -26,55 +27,45 @@ from playwright._impl._api_types import TimeoutError as PwTimeout
 from fake_useragent import UserAgent
 
 
-class AsyncObject():
+class AsyncObject:
     """Inheriting this class allows me to define an async
     __init__, So you can create an async Cleverbot object
     by doing `await CleverbotAsync(p_w)`"""
 
-    # pylint: disable=too-few-public-methods
-    # pylint: disable=invalid-overridden-method
-    # Because we've created an async init hack
-    async def __new__(cls, *a, **kw):
+    async def __new__(cls, *a, **kw):  # type: ignore
         instance = super().__new__(cls)
-        await instance.__init__(*a, **kw)
+        await instance.__init__(*a, **kw)  # type: ignore
         return instance
 
-    async def __init__(self):
+    async def __init__(self) -> None:  # type: ignore
         """Async init."""
 
 
-class Cleverbot():
+class Cleverbot:
     """ Constructs a Cleverbot chat session. Initializes the options
     to connect to Cleverbot.com via a headless Firefox browser using
     playwright, and contains the functions to connect and create chat
     sessions. Every request has the possiblity for a BrokenPipeError
     so I looped all requests until there is no error received."""
 
-    # pylint: disable=too-many-instance-attributes
-    # Eight is reasonable in this case.
-
-    # pylint: disable=unnecessary-lambda
-    # It is in fact necessary.
-
-    # pylint: disable=attribute-defined-outside-init
-    # This needs to be defined here to work properly
-    def __init__(self, p_w: object):
+    def __init__(self, p_w: Any) -> None:
         """ Initialize playwright and connect to cleverbot.com."""
-        self.p_w: object = p_w
+        self.p_w = p_w
         self.url: str = "https://www.cleverbot.com"
         self.reply: str = "id=line1"
         self.hacking: bool = False
         self.bot_response: str = ""
         self.response_string: str = ""
-        self.browser: object = self.p_w.firefox.launch()
-        self.context: object = self.browser.new_context(
-            user_agent=UserAgent().random)
+        self.browser: Any = self.p_w.firefox.launch()
+        self.context: Any = self.browser.new_context(user_agent=UserAgent(
+            fallback="Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:96.0)" +
+            " Gecko/20100101 Firefox/96.0").random)
 
-    def get_form(self):
+    def get_form(self) -> None:
         """Open new browser context page."""
         while True:
             try:
-                self.page: object = self.context.new_page()
+                self.page: Any = self.context.new_page()
                 self.page.goto(self.url,
                                timeout=10000,
                                wait_until="networkidle")
@@ -83,14 +74,14 @@ class Cleverbot():
                 continue
             break
 
-    def send_input(self, user_input: str):
+    def send_input(self, user_input: str) -> None:
         """ Submits your message through an input filter."""
         f_one: str = r"<\/?[a-z]+>|<DOCTYPE"
         f_two: str = r"/<[^>]+>/g"
         if re.search(f_one, user_input) is not None or re.search(
                 f_two, user_input) is not None:
-            self.hacking: bool = True
-            user_input: str = "I will hack you"
+            self.hacking = True
+            user_input = "I will hack you"
         while True:
             try:
                 self.page.evaluate(f'cleverbot.sendAI("{user_input}")')
@@ -99,14 +90,14 @@ class Cleverbot():
                 continue
             break
 
-    def _parse_response(self, response: object):
+    def _parse_response(self, response: Any) -> None:
         """Helper method to parse network responses for reply."""
         if "talking.txt" in response.url:
             cookies: str = response.request.headers["cookie"]
-            cookie_list: list = cookies.split("; ")
+            cookie_list: List[str] = cookies.split("; ")
             for cookie in cookie_list:
                 if cookie.startswith("CBALT"):
-                    self.bot_response: str = cookie[8:]
+                    self.bot_response = cookie[8:]
 
     def get_response(self) -> str:
         """The DOM is updated with every individual character
@@ -115,13 +106,13 @@ class Cleverbot():
         that the DOM element has received text then retrieves
         the reply."""
         if self.hacking is True:
-            self.hacking: bool = False
+            self.hacking = False
             return "No hax bro."
         self.page.on("response",
                      lambda response: self._parse_response(response))
         line: str = self.page.text_content(self.reply)
         while len(line) <= 1 and line != self.bot_response:
-            line: str = self.page.text_content(self.reply)
+            line = self.page.text_content(self.reply)
             sleep(0.1)
         self.page.close()
         return self.bot_response
@@ -138,15 +129,16 @@ class Cleverbot():
             self.single_exchange(user_input)
         return reply
 
-    def close(self):
+    def close(self) -> None:
         """Close the headless browser."""
         self.browser.close()
 
     @staticmethod
-    def connect(func):
+    def connect(func: Callable[..., Any]) -> Callable[..., Any]:
         """Decorator for connecting and starting a browser session."""
+
         @wraps(func)
-        def inner(*args, **kwargs):
+        def inner(*args: Any, **kwargs: Any) -> Any:
             """Initialize playwright."""
             with sync_playwright() as p_w:
                 c_b = Cleverbot(p_w)
@@ -162,33 +154,22 @@ class CleverbotAsync(AsyncObject):  # lgtm[py/missing-call-to-init]
     sessions. Every request has the possiblity for a BrokenPipeError
     so I looped all requests until there is no error received."""
 
-    # pylint: disable=super-init-not-called
-    # This is a hack to make an async init.
-
-    # pylint: disable=too-many-instance-attributes
-    # Eight is reasonable in this case.
-
-    # pylint: disable=unnecessary-lambda
-    # It is in fact necessary.
-
-    # pylint: disable=attribute-defined-outside-init
-    # This needs to be defined here to work properly
-    async def __init__(self, p_w: object):
+    async def __init__(self, p_w: Any):  # type: ignore
         """ Initialize playwright and connect to cleverbot.com."""
-        self.p_w: object = p_w
+        self.p_w = p_w
         self.url: str = "https://www.cleverbot.com"
         self.reply: str = "id=line1"
         self.hacking: bool = False
         self.bot_response: str = ""
-        self.browser: object = await self.p_w.firefox.launch()
-        self.context: object = await self.browser.new_context(
+        self.browser: Any = await self.p_w.firefox.launch()
+        self.context: Any = await self.browser.new_context(
             user_agent=UserAgent().random)
 
-    async def get_form(self):
+    async def get_form(self) -> None:
         """Open new browser context page."""
         while True:
             try:
-                self.page: object = await self.context.new_page()
+                self.page: Any = await self.context.new_page()
                 await self.page.goto(self.url,
                                      timeout=10000,
                                      wait_until="networkidle")
@@ -197,14 +178,14 @@ class CleverbotAsync(AsyncObject):  # lgtm[py/missing-call-to-init]
                 continue
             break
 
-    async def send_input(self, user_input: str):
+    async def send_input(self, user_input: str) -> None:
         """ Submits your message through an input filter."""
         f_one: str = r"<\/?[a-z]+>|<DOCTYPE"
         f_two: str = r"/<[^>]+>/g"
         if re.search(f_one, user_input) is not None or re.search(
                 f_two, user_input) is not None:
-            self.hacking: bool = True
-            user_input: str = "I will hack you"
+            self.hacking = True
+            user_input = "I will hack you"
         while True:
             try:
                 await self.page.evaluate(f'cleverbot.sendAI("{user_input}")')
@@ -213,14 +194,14 @@ class CleverbotAsync(AsyncObject):  # lgtm[py/missing-call-to-init]
                 continue
             break
 
-    def _parse_response(self, response: object):
+    def _parse_response(self, response: Any) -> None:
         """Helper method to parse network responses for reply."""
         if "talking.txt" in response.url:
             cookies: str = response.request.headers["cookie"]
-            cookie_list: list = cookies.split("; ")
+            cookie_list: List[str] = cookies.split("; ")
             for cookie in cookie_list:
                 if cookie.startswith("CBALT"):
-                    self.bot_response: str = cookie[8:]
+                    self.bot_response = cookie[8:]
 
     async def get_response(self) -> str:
         """The DOM is updated with every individual character
@@ -229,13 +210,13 @@ class CleverbotAsync(AsyncObject):  # lgtm[py/missing-call-to-init]
         that the DOM element has received text then retrieves
         the reply."""
         if self.hacking is True:
-            self.hacking: bool = False
+            self.hacking = False
             return "No hax bro."
         self.page.on("response",
                      lambda response: self._parse_response(response))
         line: str = await self.page.text_content(self.reply)
         while len(line) <= 1 and line != self.bot_response:
-            line: str = await self.page.text_content(self.reply)
+            line = await self.page.text_content(self.reply)
             await asyncio.sleep(0.1)
         await self.page.close()
         return self.bot_response
@@ -252,18 +233,19 @@ class CleverbotAsync(AsyncObject):  # lgtm[py/missing-call-to-init]
             await self.single_exchange(user_input)
         return reply
 
-    async def close(self):
+    async def close(self) -> None:
         """Close the headless browser."""
         await self.browser.close()
 
     @staticmethod
-    def connect(func):
+    def connect(func: Callable[..., Any]) -> Callable[..., Any]:
         """Decorator for connecting and starting a browser session."""
+
         @wraps(func)
-        async def inner(*args, **kwargs):
+        async def inner(*args: Any, **kwargs: Any) -> Any:
             """Initialize playwright"""
             async with async_playwright() as p_w:
-                c_b = await CleverbotAsync(p_w)
+                c_b = await CleverbotAsync(p_w)  # type: ignore
                 return await func(c_b, *args, **kwargs)
 
         return inner
